# A domain utility module for python

Quilts is a package for QWAN python utils

* quiltz.id:  
  a domain concept for entity ID including an ID Generator
* qulitz.results:  
  Failure and Success concepts that enables map operations
* quiltz.validators
  validation utilities for domain objects
* quiltz.parsers:
  parsers that can be used in combination with quiltz.validators
